@@ -1,11 +1,7 @@
 """Test for certbot_apache._internal.configurator implementations of reverter"""
 import shutil
 import unittest
-
-try:
-    import mock
-except ImportError: # pragma: no cover
-    from unittest import mock # type: ignore
+from unittest import mock
 
 from certbot import errors
 import util
@@ -14,15 +10,13 @@ import util
 class ConfiguratorReverterTest(util.ApacheTest):
     """Test for ApacheConfigurator reverter methods"""
 
-
     def setUp(self):  # pylint: disable=arguments-differ
         super().setUp()
 
         self.config = util.get_apache_configurator(
             self.config_path, self.vhost_path, self.config_dir, self.work_dir)
 
-        self.vh_truth = util.get_vh_truth(
-            self.temp_dir, "debian_apache_2_4/multiple_vhosts")
+        self.vh_truth = util.get_vh_truth(self.temp_dir, "debian_apache_2_4/multiple_vhosts")
 
     def tearDown(self):
         shutil.rmtree(self.config_dir)
@@ -30,17 +24,13 @@ class ConfiguratorReverterTest(util.ApacheTest):
         shutil.rmtree(self.temp_dir)
 
     def test_bad_save_checkpoint(self):
-        self.config.reverter.add_to_checkpoint = mock.Mock(
-            side_effect=errors.ReverterError)
-        self.config.parser.add_dir(
-            self.vh_truth[0].path, "Test", "bad_save_ckpt")
+        self.config.reverter.add_to_checkpoint = mock.Mock(side_effect=errors.ReverterError)
+        self.config.parser.add_dir(self.vh_truth[0].path, "Test", "bad_save_ckpt")
         self.assertRaises(errors.PluginError, self.config.save)
 
     def test_bad_save_finalize_checkpoint(self):
-        self.config.reverter.finalize_checkpoint = mock.Mock(
-            side_effect=errors.ReverterError)
-        self.config.parser.add_dir(
-            self.vh_truth[0].path, "Test", "bad_save_ckpt")
+        self.config.reverter.finalize_checkpoint = mock.Mock(side_effect=errors.ReverterError)
+        self.config.parser.add_dir(self.vh_truth[0].path, "Test", "bad_save_ckpt")
         self.assertRaises(errors.PluginError, self.config.save, "Title")
 
     def test_finalize_save(self):
@@ -72,8 +62,7 @@ class ConfiguratorReverterTest(util.ApacheTest):
         self.assertEqual(mock_load.call_count, 1)
 
     def test_rollback_error(self):
-        self.config.reverter.rollback_checkpoints = mock.Mock(
-            side_effect=errors.ReverterError)
+        self.config.reverter.rollback_checkpoints = mock.Mock(side_effect=errors.ReverterError)
         self.assertRaises(errors.PluginError, self.config.rollback_checkpoints)
 
     def test_recovery_routine_reload(self):
