@@ -1,10 +1,6 @@
 """Test certbot_apache._internal.display_ops."""
 import unittest
-
-try:
-    import mock
-except ImportError:  # pragma: no cover
-    from unittest import mock  # type: ignore
+from unittest import mock
 
 from certbot import errors
 from certbot.display import util as display_util
@@ -23,7 +19,7 @@ class SelectVhostMultiTest(unittest.TestCase):
             self.base_dir, "debian_apache_2_4/multiple_vhosts")
 
     def test_select_no_input(self):
-        self.assertFalse(select_vhost_multiple([]))
+        self.assertEqual(len(select_vhost_multiple([])), 0)
 
     @certbot_util.patch_display_util()
     def test_select_correct(self, mock_util):
@@ -33,15 +29,15 @@ class SelectVhostMultiTest(unittest.TestCase):
         vhs = select_vhost_multiple([self.vhosts[3],
                                      self.vhosts[2],
                                      self.vhosts[1]])
-        self.assertTrue(self.vhosts[2] in vhs)
-        self.assertTrue(self.vhosts[3] in vhs)
-        self.assertFalse(self.vhosts[1] in vhs)
+        self.assertIn(self.vhosts[2], vhs)
+        self.assertIn(self.vhosts[3], vhs)
+        self.assertNotIn(self.vhosts[1], vhs)
 
     @certbot_util.patch_display_util()
     def test_select_cancel(self, mock_util):
         mock_util().checklist.return_value = (display_util.CANCEL, "whatever")
         vhs = select_vhost_multiple([self.vhosts[2], self.vhosts[3]])
-        self.assertFalse(vhs)
+        self.assertEqual(vhs, [])
 
 
 class SelectVhostTest(unittest.TestCase):
@@ -68,7 +64,7 @@ class SelectVhostTest(unittest.TestCase):
         try:
             self._call(self.vhosts)
         except errors.MissingCommandlineFlag as e:
-            self.assertTrue("vhost ambiguity" in str(e))
+            self.assertIn("vhost ambiguity", str(e))
 
     @certbot_util.patch_display_util()
     def test_more_info_cancel(self, mock_util):
@@ -76,10 +72,10 @@ class SelectVhostTest(unittest.TestCase):
             (display_util.CANCEL, -1),
         ]
 
-        self.assertEqual(None, self._call(self.vhosts))
+        self.assertIsNone(self._call(self.vhosts))
 
     def test_no_vhosts(self):
-        self.assertEqual(self._call([]), None)
+        self.assertIsNone(self._call([]))
 
     @mock.patch("certbot_apache._internal.display_ops.display_util")
     @mock.patch("certbot_apache._internal.display_ops.logger")
