@@ -27,14 +27,14 @@ class VirtualHostTest(unittest.TestCase):
             "certbot_apache._internal.obj.Addr(('127.0.0.1', '443'))")
 
     def test_eq(self):
-        self.assertTrue(self.vhost1b == self.vhost1)
-        self.assertFalse(self.vhost1 == self.vhost2)
+        self.assertEqual(self.vhost1b, self.vhost1)
+        self.assertNotEqual(self.vhost1, self.vhost2)
         self.assertEqual(str(self.vhost1b), str(self.vhost1))
-        self.assertFalse(self.vhost1b == 1234)
+        self.assertNotEqual(self.vhost1b, 1234)
 
     def test_ne(self):
-        self.assertTrue(self.vhost1 != self.vhost2)
-        self.assertFalse(self.vhost1 != self.vhost1b)
+        self.assertNotEqual(self.vhost1, self.vhost2)
+        self.assertEqual(self.vhost1, self.vhost1b)
 
     def test_conflicts(self):
         from certbot_apache._internal.obj import Addr
@@ -44,15 +44,14 @@ class VirtualHostTest(unittest.TestCase):
             "fp", "vhp",
             {Addr.fromstring("*:443"), Addr.fromstring("1.2.3.4:443")},
             False, False)
-        self.assertTrue(complex_vh.conflicts([self.addr1]))
-        self.assertTrue(complex_vh.conflicts([self.addr2]))
-        self.assertFalse(complex_vh.conflicts([self.addr_default]))
+        self.assertIs(complex_vh.conflicts([self.addr1]), True)
+        self.assertIs(complex_vh.conflicts([self.addr2]), True)
+        self.assertIs(complex_vh.conflicts([self.addr_default]), False)
 
-        self.assertTrue(self.vhost1.conflicts([self.addr2]))
-        self.assertFalse(self.vhost1.conflicts([self.addr_default]))
+        self.assertIs(self.vhost1.conflicts([self.addr2]), True)
+        self.assertIs(self.vhost1.conflicts([self.addr_default]), False)
 
-        self.assertFalse(self.vhost2.conflicts([self.addr1,
-                                                self.addr_default]))
+        self.assertIs(self.vhost2.conflicts([self.addr1, self.addr_default]), False)
 
     def test_same_server(self):
         from certbot_apache._internal.obj import VirtualHost
@@ -67,12 +66,12 @@ class VirtualHostTest(unittest.TestCase):
             "fp", "vhp", {self.addr2, self.addr_default},
             False, False, None)
 
-        self.assertTrue(self.vhost1.same_server(self.vhost2))
-        self.assertTrue(no_name1.same_server(no_name2))
+        self.assertIs(self.vhost1.same_server(self.vhost2), True)
+        self.assertIs(no_name1.same_server(no_name2), True)
 
-        self.assertFalse(self.vhost1.same_server(no_name1))
-        self.assertFalse(no_name1.same_server(no_name3))
-        self.assertFalse(no_name1.same_server(no_name4))
+        self.assertIs(self.vhost1.same_server(no_name1), False)
+        self.assertIs(no_name1.same_server(no_name3), False)
+        self.assertIs(no_name1.same_server(no_name4), False)
 
 
 class AddrTest(unittest.TestCase):
@@ -88,9 +87,9 @@ class AddrTest(unittest.TestCase):
         self.addr_default = Addr.fromstring("_default_:443")
 
     def test_wildcard(self):
-        self.assertFalse(self.addr.is_wildcard())
-        self.assertTrue(self.addr1.is_wildcard())
-        self.assertTrue(self.addr2.is_wildcard())
+        self.assertIs(self.addr.is_wildcard(), False)
+        self.assertIs(self.addr1.is_wildcard(), True)
+        self.assertIs(self.addr2.is_wildcard(), True)
 
     def test_get_sni_addr(self):
         from certbot_apache._internal.obj import Addr
@@ -103,38 +102,38 @@ class AddrTest(unittest.TestCase):
 
     def test_conflicts(self):
         # Note: Defined IP is more important than defined port in match
-        self.assertTrue(self.addr.conflicts(self.addr1))
-        self.assertTrue(self.addr.conflicts(self.addr2))
-        self.assertTrue(self.addr.conflicts(self.addr_defined))
-        self.assertFalse(self.addr.conflicts(self.addr_default))
+        self.assertIs(self.addr.conflicts(self.addr1), True)
+        self.assertIs(self.addr.conflicts(self.addr2), True)
+        self.assertIs(self.addr.conflicts(self.addr_defined), True)
+        self.assertIs(self.addr.conflicts(self.addr_default), False)
 
-        self.assertFalse(self.addr1.conflicts(self.addr))
-        self.assertTrue(self.addr1.conflicts(self.addr_defined))
-        self.assertFalse(self.addr1.conflicts(self.addr_default))
+        self.assertIs(self.addr1.conflicts(self.addr), False)
+        self.assertIs(self.addr1.conflicts(self.addr_defined), True)
+        self.assertIs(self.addr1.conflicts(self.addr_default), False)
 
-        self.assertFalse(self.addr_defined.conflicts(self.addr1))
-        self.assertFalse(self.addr_defined.conflicts(self.addr2))
-        self.assertFalse(self.addr_defined.conflicts(self.addr))
-        self.assertFalse(self.addr_defined.conflicts(self.addr_default))
+        self.assertIs(self.addr_defined.conflicts(self.addr1), False)
+        self.assertIs(self.addr_defined.conflicts(self.addr2), False)
+        self.assertIs(self.addr_defined.conflicts(self.addr), False)
+        self.assertIs(self.addr_defined.conflicts(self.addr_default), False)
 
-        self.assertTrue(self.addr_default.conflicts(self.addr))
-        self.assertTrue(self.addr_default.conflicts(self.addr1))
-        self.assertTrue(self.addr_default.conflicts(self.addr_defined))
+        self.assertIs(self.addr_default.conflicts(self.addr), True)
+        self.assertIs(self.addr_default.conflicts(self.addr1), True)
+        self.assertIs(self.addr_default.conflicts(self.addr_defined), True)
 
         # Self test
-        self.assertTrue(self.addr.conflicts(self.addr))
-        self.assertTrue(self.addr1.conflicts(self.addr1))
+        self.assertIs(self.addr.conflicts(self.addr), True)
+        self.assertIs(self.addr1.conflicts(self.addr1), True)
         # This is a tricky one...
-        self.assertTrue(self.addr1.conflicts(self.addr2))
+        self.assertIs(self.addr1.conflicts(self.addr2), True)
 
     def test_equal(self):
-        self.assertTrue(self.addr1 == self.addr2)
-        self.assertFalse(self.addr == self.addr1)
-        self.assertFalse(self.addr == 123)
+        self.assertEqual(self.addr1, self.addr2)
+        self.assertNotEqual(self.addr, self.addr1)
+        self.assertNotEqual(self.addr, 123)
 
     def test_not_equal(self):
-        self.assertFalse(self.addr1 != self.addr2)
-        self.assertTrue(self.addr != self.addr1)
+        self.assertEqual(self.addr1, self.addr2)
+        self.assertNotEqual(self.addr, self.addr1)
 
 
 if __name__ == "__main__":
